package jalview.ext.ensembl;

import static org.testng.AssertJUnit.assertEquals;

import org.testng.Assert;
import org.testng.annotations.Test;

public class EnsemblProteinTest
{

  @Test(groups = "Functional")
  public void testIsValidReference() throws Exception
  {
    EnsemblSequenceFetcher esq = new EnsemblProtein();
    Assert.assertTrue(esq.isValidReference("CCDS5863.1"));
    Assert.assertTrue(esq.isValidReference("ENSP00000288602"));
    Assert.assertFalse(esq.isValidReference("ENST00000288602"));
    Assert.assertFalse(esq.isValidReference("ENSG00000288602"));
    // non-human species having a 3 character identifier included:
    Assert.assertTrue(esq.isValidReference("ENSMUSP00000099398"));
  }

  @Test(groups = "Functional")
  public void testGetAccesionIdFromQuery() throws Exception
  {
    EnsemblSequenceFetcher esq = new EnsemblProtein();
    assertEquals("ENSP00000288602",
            esq.getAccessionIdFromQuery("ENSP00000288602"));
    assertEquals("ENSMUSP00000288602",
            esq.getAccessionIdFromQuery("ENSMUSP00000288602"));

    // ENST converted to ENSP
    assertEquals("ENSP00000288602",
            esq.getAccessionIdFromQuery("ENST00000288602"));
    assertEquals("ENSMUSP00000288602",
            esq.getAccessionIdFromQuery("ENSMUST00000288602"));

    // with valid separator:
    assertEquals("ENSP00000288604",
            esq.getAccessionIdFromQuery("ENSP00000288604 ENSP00000288602"));

    // with wrong separator:
    assertEquals("ENSP00000288604,ENSP00000288602",
            esq.getAccessionIdFromQuery("ENSP00000288604,ENSP00000288602"));
  }

}
